"Package information file"
# Format and usage strongly inspired by AGProjects/python-application.


__project__ = "callsignlookuptools"
__summary__ = "QRZ, Callook, HamQTH, and QRZCQ API interface with sync and async support"
__webpage__ = "https://callsignlookuptools.miaow.io"

__version__ = "1.1.0"

__author__ = "classabbyamp, 0x5c"
__email__ = "dev@placeviolette.net, dev@0x5c.io"

__license__ = "BSD 3-Clause"
__copyright__ = "2021-2023"
